pub struct Event {Show 18 fields
item: RefCell<Option<Arc<EventTimelineItem>>>,
event_id_string: PhantomData<Option<String>>,
sender_id_string: PhantomData<String>,
timestamp: PhantomData<DateTime>,
formatted_timestamp: PhantomData<String>,
source: PhantomData<Option<String>>,
has_source: PhantomData<bool>,
state: Cell<MessageState>,
is_edited: PhantomData<bool>,
latest_edit_source: PhantomData<String>,
latest_edit_event_id_string: PhantomData<String>,
latest_edit_timestamp: PhantomData<Option<DateTime>>,
latest_edit_formatted_timestamp: PhantomData<String>,
is_highlighted: PhantomData<bool>,
reactions: ReactionList,
read_receipts: OnceCell<ListStore>,
has_read_receipts: PhantomData<bool>,
header_state: Cell<EventHeaderState>,
}Fields
item: RefCell<Option<Arc<EventTimelineItem>>>The underlying SDK timeline item.
event_id_string: PhantomData<Option<String>>The global permanent ID of this event, if it has been received from the server, as a string.
sender_id_string: PhantomData<String>The ID of the sender of this event, as a string.
timestamp: PhantomData<DateTime>The timestamp of this event, as a GDateTime.
formatted_timestamp: PhantomData<String>The formatted timestamp of this event.
source: PhantomData<Option<String>>The pretty-formatted JSON source, if it has been echoed back by the server.
has_source: PhantomData<bool>Whether we have the JSON source of this event.
state: Cell<MessageState>The state of this event.
is_edited: PhantomData<bool>Whether this event was edited.
latest_edit_source: PhantomData<String>The pretty-formatted JSON source for the latest edit of this event.
This string is empty if the event is not edited.
latest_edit_event_id_string: PhantomData<String>The ID for the latest edit of this event, as a string.
This string is empty if the event is not edited.
latest_edit_timestamp: PhantomData<Option<DateTime>>The timestamp for the latest edit of this event, as a GDateTime,
if any.
latest_edit_formatted_timestamp: PhantomData<String>The formatted timestamp for the latest edit of this event.
This string is empty if the event is not edited.
is_highlighted: PhantomData<bool>Whether this event should be highlighted.
reactions: ReactionListThe reactions on this event.
read_receipts: OnceCell<ListStore>The read receipts on this event.
has_read_receipts: PhantomData<bool>Whether this event has any read receipt.
header_state: Cell<EventHeaderState>The state of the header of the event in the room history.
Implementations
Sourceimpl Event
impl Event
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl Event
impl Event
Sourcepub(super) fn identifier(&self) -> TimelineEventItemId
pub(super) fn identifier(&self) -> TimelineEventItemId
The global permanent or temporary identifier of this event.
Sourcepub(super) fn event_id(&self) -> Option<OwnedEventId>
pub(super) fn event_id(&self) -> Option<OwnedEventId>
The global permanent ID of this event, if it has been received from the server.
Sourcefn event_id_string(&self) -> Option<String>
fn event_id_string(&self) -> Option<String>
The global permanent ID of this event, if it has been received from the server, as a string.
Sourcepub(crate) fn transaction_id(&self) -> Option<OwnedTransactionId>
pub(crate) fn transaction_id(&self) -> Option<OwnedTransactionId>
The temporary ID of this event, if it has been sent with this session.
Sourcefn sender_id_string(&self) -> String
fn sender_id_string(&self) -> String
The ID of the sender of this event, as a string.
Sourcepub(super) fn origin_server_ts(&self) -> MilliSecondsSinceUnixEpoch
pub(super) fn origin_server_ts(&self) -> MilliSecondsSinceUnixEpoch
The timestamp of this event, as the number of milliseconds since Unix Epoch.
Sourcefn formatted_timestamp(&self) -> String
fn formatted_timestamp(&self) -> String
The formatted timestamp of this event.
Sourcepub(super) fn raw(&self) -> Option<Raw<AnySyncTimelineEvent>>
pub(super) fn raw(&self) -> Option<Raw<AnySyncTimelineEvent>>
The raw JSON source, if it has been echoed back by the server.
Sourcefn source(&self) -> Option<String>
fn source(&self) -> Option<String>
The pretty-formatted JSON source, if it has been echoed back by the server.
Sourcefn has_source(&self) -> bool
fn has_source(&self) -> bool
Whether we have the JSON source.
Sourcefn compute_state(&self) -> MessageState
fn compute_state(&self) -> MessageState
Compute the current state of this event.
Sourcefn update_state(&self)
fn update_state(&self)
Update the state of this event.
Sourcefn latest_edit_raw(&self) -> Option<Raw<AnySyncTimelineEvent>>
fn latest_edit_raw(&self) -> Option<Raw<AnySyncTimelineEvent>>
The JSON source for the latest edit of this event, if any.
Sourcefn latest_edit_source(&self) -> String
fn latest_edit_source(&self) -> String
The pretty-formatted JSON source for the latest edit of this event.
This string is empty if the event is not edited.
Sourcefn latest_edit_event_id_string(&self) -> String
fn latest_edit_event_id_string(&self) -> String
The ID of the latest edit of this Event.
This string is empty if the event is not edited.
Sourcefn latest_edit_timestamp(&self) -> Option<DateTime>
fn latest_edit_timestamp(&self) -> Option<DateTime>
The timestamp of the latest edit of this Event, as a GDateTime,
if any.
Sourcefn latest_edit_formatted_timestamp(&self) -> String
fn latest_edit_formatted_timestamp(&self) -> String
The formatted timestamp of the latest edit of this Event.
Sourcefn is_highlighted(&self) -> bool
fn is_highlighted(&self) -> bool
Whether this Event should be highlighted.
Sourcefn read_receipts(&self) -> &ListStore
fn read_receipts(&self) -> &ListStore
The read receipts on this event.
Sourcefn read_receipts_owned(&self) -> ListStore
fn read_receipts_owned(&self) -> ListStore
The owned read receipts on this event.
Sourcefn update_read_receipts(
&self,
new_read_receipts: &IndexMap<OwnedUserId, Receipt>,
)
fn update_read_receipts( &self, new_read_receipts: &IndexMap<OwnedUserId, Receipt>, )
Update the read receipts list with the given receipts.
Sourcefn has_read_receipts(&self) -> bool
fn has_read_receipts(&self) -> bool
Whether this event has any read receipt.
Sourcefn set_header_state(&self, state: EventHeaderState)
fn set_header_state(&self, state: EventHeaderState)
Set the state of the header of the event in the room history.